// ========================================
// AK-47 Kalashnikov assault rifle
// -----------------------------------------
// Made for Persistence of vision 3.6
//==========================================  
// Copyright 2007 Gilles Tran http://www.oyonale.com
// -----------------------------------------
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/3.0/ 
// or send a letter to Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.
// You are free:
// - to copy, distribute, display, and perform the work
// - to make derivative works
// - to make commercial use of the work
// Under the following conditions:
// - Attribution. You must give the original author credit.
// - For any reuse or distribution, you must make clear to others the license terms of this work.
// - Any of these conditions can be waived if you get permission from the copyright holder.
// Your fair use and other rights are in no way affected by the above. 
//========================================== 
// Render with +W800 +H600
// no antialiasing needed if the focal blur is turned on
#include "colors.inc"

global_settings {
    radiosity {
        pretrace_start 0.08           // start pretrace at this size
        pretrace_end   0.04           // end pretrace at this size
        count 100                      // higher -> higher quality (1..1600) [35]
        nearest_count 5               // higher -> higher quality (1..10) [5]
        error_bound 0.5               // higher -> smoother, less accurate [1.8]
        recursion_limit 2             // how much interreflections are calculated (1..5+) [3]
        low_error_factor .5           // reduce error_bound during last pretrace step
        gray_threshold 0.0            // increase for weakening colors (0..1) [0]
        minimum_reuse 0.015           // reuse of old radiosity samples [0.015]
        brightness 1                  // brightness of radiosity effects (0..1) [1]
        
        adc_bailout 0.01/2
        normal on                   // take surface normals into account [off]
    }
    assumed_gamma 1
}


camera {
        location y*40-z*60
        direction z*1.9
        up y
        right -x*image_width/image_height
        look_at y*0

       aperture 1           // [0...N] larger is narrower depth of field (blurrier)
        blur_samples 50        // number of rays per pixel for sampling
        focal_point <0,0,0>    // point that is in focus <X,Y,Z>
        confidence 0.95           // [0...<1] when to move on while sampling (smaller is less accurate)
        variance 1/200            // [0...1] how precise to calculate (smaller is more accurate)
    

}
 
light_source {
    -z*1000
    color Orange*4 // rgb <255,230,200>*3/255

    area_light 50*z,50*y, 5,5 adaptive 1 jitter orient circular
    rotate x*20
    rotate -y*100
}

 
#declare T_Metal=texture{
    pigment{
        bozo
        scale 1/40
        turbulence 1
        lambda 4
        scale <1,1,1>
        color_map{
            [0.5 rgb <9,11,17>*0.2/255]
            [1 rgb <9,11,17>*0.3/255]
        }
    }
    finish{ambient 0 diffuse 1 roughness 1/10 metallic specular 1
        reflection {0.1,1 metallic}
    }
}

#declare T_Wood =texture{
    pigment{
        wood
        turbulence 0.2
        lambda 4
        scale 1
        rotate y*30
        rotate x*20
        color_map{
            [0 rgb <127, 67, 40>/255]
            [1 rgb <43, 22, 13>/255]
        }
    }
    finish{ambient 0 diffuse 0.6 specular 1 roughness 1/10 reflection {0,0.16}} 
}

sky_sphere{
    pigment{
        image_map{jpeg "sky.jpg"}
        warp {spherical}
        rotate y*180
    }
}

plane{y,0
    texture{
        pigment{image_map{jpeg "concrete2.jpg"}}
        normal{bump_map{jpeg "concrete2.jpg" bump_size 2}}
        finish{ambient 0 diffuse 0.6}
        scale 100
        rotate x*90
        translate z*60+x*50
    }
}

#include "ak47.inc"
#declare AK47 =object{AK47 rotate y*180 rotate z*90.705}
object{AK47
    rotate y*130
    translate y*1.282-x*8+z*10
}
object{AK47
    rotate y*20 
    translate y*1.282-x*20-z*30
}
object{AK47
    rotate y*10 
    translate y*1.282-x*3-z*40
}

object{AK47
    rotate y*0 
    translate y*1.282+x*10-z*40
}

object{AK47
    rotate -y*20
    translate y*1.282+x*13+z*20
}


